@@ -53,7 +53,13 @@
 #include <nsMemory.h>
 #include <nsEmbedString.h>
 #include <nsIPrefService.h>
-#include <nsICommandManager.h>
+#if XULRUNNER18
+  #include <commandhandler/nsICommandManager.h>
+  #include <locale/nsILocaleService.h>
+#else
+  #include <nsICommandManager.h>
+  #include <nsILocaleService.h>
+#endif
 #include <nsIInterfaceRequestorUtils.h>
 #include <nsIDOMWindow.h>
 
@@ -65,7 +71,6 @@
 #include <nsILocalFile.h>
 #include <nsIDOMMouseEvent.h>
 #include <nsIWebBrowserFind.h>
-#include <nsILocaleService.h>
 #include <nsStringAPI.h>
 
 #include "utils/utils.h"
@@ -205,10 +210,17 @@ gecko_utils_init(void)
 #ifdef XPCOM_GLUE
 	NS_LogInit();
 
+#if XULRUNNER191
+        static const GREVersionRange greVersion = {
+                "1.9.1", PR_TRUE,
+                "1.9.2", PR_FALSE
+        };
+#else
         static const GREVersionRange greVersion = {
                 "1.9a", PR_TRUE,
                 "1.9.1", PR_FALSE
         };
+#endif
 
         char xpcomLocation[4096];
         rv = GRE_GetGREPathWithProperties(&greVersion, 1, nsnull, 0, xpcomLocation, 4096);
